@@ -1,11 +1,11 @@
 use anyhow::Result;
 use clap::{App, AppSettings, Arg};
-use std::sync::Arc;
-use tokio::time::Duration;
-
 use interceptor::registry::Registry;
+use std::io::Write;
 use std::sync::atomic::{AtomicI32, Ordering};
+use std::sync::Arc;
 use tokio::sync::Mutex;
+use tokio::time::Duration;
 use webrtc::api::interceptor_registry::register_default_interceptors;
 use webrtc::api::media_engine::MediaEngine;
 use webrtc::api::APIBuilder;
@@ -14,31 +14,14 @@ use webrtc::data::data_channel::RTCDataChannel;
 use webrtc::peer::configuration::RTCConfiguration;
 use webrtc::peer::ice::ice_server::RTCIceServer;
 use webrtc::peer::peer_connection_state::RTCPeerConnectionState;
-use webrtc::peer::sdp::session_description::{RTCSessionDescription, RTCSessionDescriptionSerde};
+use webrtc::peer::sdp::session_description::RTCSessionDescription;
 use webrtc::util::math_rand_alpha;
 
-//use std::io::Write;
-
 #[tokio::main]
 async fn main() -> Result<()> {
-    /*env_logger::Builder::new()
-    .format(|buf, record| {
-        writeln!(
-            buf,
-            "{}:{} [{}] {} - {}",
-            record.file().unwrap_or("unknown"),
-            record.line().unwrap_or(0),
-            record.level(),
-            chrono::Local::now().format("%H:%M:%S.%6f"),
-            record.args()
-        )
-    })
-    .filter(None, log::LevelFilter::Trace)
-    .init();*/
-
     let mut app = App::new("data-channels-close")
         .version("0.1.0")
-        .author("Rain Liu <yuliu@webrtc.rs>")
+        .author("Rain Liu <yliu@webrtc.rs>")
         .about("An example of Data-Channels-Close.")
         .setting(AppSettings::DeriveDisplayOrder)
         .setting(AppSettings::SubcommandsNegateReqs)
@@ -47,6 +30,12 @@ async fn main() -> Result<()> {
                 .help("Prints more detailed help information")
                 .long("fullhelp"),
         )
+        .arg(
+            Arg::with_name("debug")
+                .long("debug")
+                .short("d")
+                .help("Prints debug log information"),
+        )
         .arg(
             Arg::with_name("close-after")
                 .required_unless("FULLHELP")
@@ -70,6 +59,23 @@ async fn main() -> Result<()> {
             .to_owned()
             .parse::<i32>()?,
     ));
+    let debug = matches.is_present("debug");
+    if debug {
+        env_logger::Builder::new()
+            .format(|buf, record| {
+                writeln!(
+                    buf,
+                    "{}:{} [{}] {} - {}",
+                    record.file().unwrap_or("unknown"),
+                    record.line().unwrap_or(0),
+                    record.level(),
+                    chrono::Local::now().format("%H:%M:%S.%6f"),
+                    record.args()
+                )
+            })
+            .filter(None, log::LevelFilter::Trace)
+            .init();
+    }
 
     // Everything below is the WebRTC-rs API! Thanks for using it ❤️.
 
@@ -189,10 +195,9 @@ async fn main() -> Result<()> {
         .await;
 
     // Wait for the offer to be pasted
-    let mut offer = RTCSessionDescription::default();
     let line = signal::must_read_stdin()?;
     let desc_data = signal::decode(line.as_str())?;
-    offer.serde = serde_json::from_str::<RTCSessionDescriptionSerde>(&desc_data)?;
+    let offer = serde_json::from_str::<RTCSessionDescription>(&desc_data)?;
 
     // Set the remote SessionDescription
     peer_connection.set_remote_description(offer).await?;
@@ -213,7 +218,7 @@ async fn main() -> Result<()> {
 
     // Output the answer in base64 so we can paste it in browser
     if let Some(local_desc) = peer_connection.local_description().await {
-        let json_str = serde_json::to_string(&local_desc.serde)?;
+        let json_str = serde_json::to_string(&local_desc)?;
         let b64 = signal::encode(&json_str);
         println!("{}", b64);
     } else {
