@@ -1,10 +1,10 @@
 use anyhow::Result;
+use bytes::Bytes;
 use clap::{App, AppSettings, Arg};
+use interceptor::registry::Registry;
+use std::io::Write;
 use std::sync::Arc;
 use tokio::time::Duration;
-
-use bytes::Bytes;
-use interceptor::registry::Registry;
 use webrtc::api::interceptor_registry::register_default_interceptors;
 use webrtc::api::media_engine::MediaEngine;
 use webrtc::api::setting_engine::SettingEngine;
@@ -12,33 +12,16 @@ use webrtc::api::APIBuilder;
 use webrtc::peer::configuration::RTCConfiguration;
 use webrtc::peer::ice::ice_server::RTCIceServer;
 use webrtc::peer::peer_connection_state::RTCPeerConnectionState;
-use webrtc::peer::sdp::session_description::{RTCSessionDescription, RTCSessionDescriptionSerde};
+use webrtc::peer::sdp::session_description::RTCSessionDescription;
 use webrtc::util::math_rand_alpha;
 
-//use std::io::Write;
-
 const MESSAGE_SIZE: usize = 1500;
 
 #[tokio::main]
 async fn main() -> Result<()> {
-    /*env_logger::Builder::new()
-    .format(|buf, record| {
-        writeln!(
-            buf,
-            "{}:{} [{}] {} - {}",
-            record.file().unwrap_or("unknown"),
-            record.line().unwrap_or(0),
-            record.level(),
-            chrono::Local::now().format("%H:%M:%S.%6f"),
-            record.args()
-        )
-    })
-    .filter(None, log::LevelFilter::Trace)
-    .init();*/
-
     let mut app = App::new("data-channels-detach-create")
         .version("0.1.0")
-        .author("Rain Liu <yuliu@webrtc.rs>")
+        .author("Rain Liu <yliu@webrtc.rs>")
         .about("An example of Data-Channels-Detach-Create.")
         .setting(AppSettings::DeriveDisplayOrder)
         .setting(AppSettings::SubcommandsNegateReqs)
@@ -46,6 +29,12 @@ async fn main() -> Result<()> {
             Arg::with_name("FULLHELP")
                 .help("Prints more detailed help information")
                 .long("fullhelp"),
+        )
+        .arg(
+            Arg::with_name("debug")
+                .long("debug")
+                .short("d")
+                .help("Prints debug log information"),
         );
 
     let matches = app.clone().get_matches();
@@ -55,6 +44,24 @@ async fn main() -> Result<()> {
         std::process::exit(0);
     }
 
+    let debug = matches.is_present("debug");
+    if debug {
+        env_logger::Builder::new()
+            .format(|buf, record| {
+                writeln!(
+                    buf,
+                    "{}:{} [{}] {} - {}",
+                    record.file().unwrap_or("unknown"),
+                    record.line().unwrap_or(0),
+                    record.level(),
+                    chrono::Local::now().format("%H:%M:%S.%6f"),
+                    record.args()
+                )
+            })
+            .filter(None, log::LevelFilter::Trace)
+            .init();
+    }
+
     // Everything below is the WebRTC-rs API! Thanks for using it ❤️.
 
     // Create a MediaEngine object to configure the supported codec
@@ -166,7 +173,7 @@ async fn main() -> Result<()> {
 
     // Output the offer in base64 so we can paste it in browser
     if let Some(local_desc) = peer_connection.local_description().await {
-        let json_str = serde_json::to_string(&local_desc.serde)?;
+        let json_str = serde_json::to_string(&local_desc)?;
         let b64 = signal::encode(&json_str);
         println!("{}", b64);
     } else {
@@ -174,10 +181,9 @@ async fn main() -> Result<()> {
     }
 
     // Wait for the answer to be pasted
-    let mut answer = RTCSessionDescription::default();
     let line = signal::must_read_stdin()?;
     let desc_data = signal::decode(line.as_str())?;
-    answer.serde = serde_json::from_str::<RTCSessionDescriptionSerde>(&desc_data)?;
+    let answer = serde_json::from_str::<RTCSessionDescription>(&desc_data)?;
 
     // Apply the answer as the remote description
     peer_connection.set_remote_description(answer).await?;
