@@ -1,6 +1,7 @@
 use anyhow::Result;
 use clap::{App, AppSettings, Arg};
 use serde::{Deserialize, Serialize};
+use std::io::Write;
 use std::sync::Arc;
 use tokio::time::Duration;
 use webrtc::api::APIBuilder;
@@ -16,25 +17,8 @@ use webrtc::peer::ice::ice_gather::RTCIceGatherOptions;
 use webrtc::peer::ice::ice_server::RTCIceServer;
 use webrtc::util::math_rand_alpha;
 
-//use std::io::Write;
-
 #[tokio::main]
 async fn main() -> Result<()> {
-    /*env_logger::Builder::new()
-    .format(|buf, record| {
-        writeln!(
-            buf,
-            "{}:{} [{}] {} - {}",
-            record.file().unwrap_or("unknown"),
-            record.line().unwrap_or(0),
-            record.level(),
-            chrono::Local::now().format("%H:%M:%S.%6f"),
-            record.args()
-        )
-    })
-    .filter(None, log::LevelFilter::Trace)
-    .init();*/
-
     let mut app = App::new("ortc")
         .version("0.1.0")
         .author("Rain Liu <yliu@webrtc.rs>")
@@ -46,6 +30,12 @@ async fn main() -> Result<()> {
                 .help("Prints more detailed help information")
                 .long("fullhelp"),
         )
+        .arg(
+            Arg::with_name("debug")
+                .long("debug")
+                .short("d")
+                .help("Prints debug log information"),
+        )
         .arg(
             Arg::with_name("offer")
                 .long("offer")
@@ -60,6 +50,23 @@ async fn main() -> Result<()> {
     }
 
     let is_offer = matches.is_present("offer");
+    let debug = matches.is_present("debug");
+    if debug {
+        env_logger::Builder::new()
+            .format(|buf, record| {
+                writeln!(
+                    buf,
+                    "{}:{} [{}] {} - {}",
+                    record.file().unwrap_or("unknown"),
+                    record.line().unwrap_or(0),
+                    record.level(),
+                    chrono::Local::now().format("%H:%M:%S.%6f"),
+                    record.args()
+                )
+            })
+            .filter(None, log::LevelFilter::Trace)
+            .init();
+    }
 
     // Everything below is the Pion WebRTC (ORTC) API! Thanks for using it ❤️.
 
