@@ -3,12 +3,12 @@ pub mod track_remote;
 
 use track_remote::*;
 
-use crate::media::interceptor::{stream_info::StreamInfo, *};
+use interceptor::stream_info::StreamInfo;
+use interceptor::{RTCPReader, RTPReader};
 use std::sync::Arc;
 
 /// TrackStreams maintains a mapping of RTP/RTCP streams to a specific track
 /// a RTPReceiver may contain multiple streams if we are dealing with Multicast
-#[derive(Default)]
 pub(crate) struct TrackStreams {
     pub(crate) track: Arc<TrackRemote>,
 
