@@ -2,7 +2,7 @@ use std::fmt;
 
 /// ICEGatheringState describes the state of the candidate gathering process.
 #[derive(Debug, Copy, Clone, PartialEq)]
-pub enum ICEGatheringState {
+pub enum RTCIceGatheringState {
     Unspecified,
 
     /// ICEGatheringStateNew indicates that any of the ICETransports are
@@ -19,9 +19,9 @@ pub enum ICEGatheringState {
     Complete,
 }
 
-impl Default for ICEGatheringState {
+impl Default for RTCIceGatheringState {
     fn default() -> Self {
-        ICEGatheringState::Unspecified
+        RTCIceGatheringState::Unspecified
     }
 }
 
@@ -30,23 +30,23 @@ const ICE_GATHERING_STATE_GATHERING_STR: &str = "gathering";
 const ICE_GATHERING_STATE_COMPLETE_STR: &str = "complete";
 
 /// takes a string and converts it to ICEGatheringState
-impl From<&str> for ICEGatheringState {
+impl From<&str> for RTCIceGatheringState {
     fn from(raw: &str) -> Self {
         match raw {
-            ICE_GATHERING_STATE_NEW_STR => ICEGatheringState::New,
-            ICE_GATHERING_STATE_GATHERING_STR => ICEGatheringState::Gathering,
-            ICE_GATHERING_STATE_COMPLETE_STR => ICEGatheringState::Complete,
-            _ => ICEGatheringState::Unspecified,
+            ICE_GATHERING_STATE_NEW_STR => RTCIceGatheringState::New,
+            ICE_GATHERING_STATE_GATHERING_STR => RTCIceGatheringState::Gathering,
+            ICE_GATHERING_STATE_COMPLETE_STR => RTCIceGatheringState::Complete,
+            _ => RTCIceGatheringState::Unspecified,
         }
     }
 }
 
-impl fmt::Display for ICEGatheringState {
+impl fmt::Display for RTCIceGatheringState {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         match *self {
-            ICEGatheringState::New => write!(f, "{}", ICE_GATHERING_STATE_NEW_STR),
-            ICEGatheringState::Gathering => write!(f, "{}", ICE_GATHERING_STATE_GATHERING_STR),
-            ICEGatheringState::Complete => {
+            RTCIceGatheringState::New => write!(f, "{}", ICE_GATHERING_STATE_NEW_STR),
+            RTCIceGatheringState::Gathering => write!(f, "{}", ICE_GATHERING_STATE_GATHERING_STR),
+            RTCIceGatheringState::Complete => {
                 write!(f, "{}", ICE_GATHERING_STATE_COMPLETE_STR)
             }
             _ => write!(f, "{}", crate::UNSPECIFIED_STR),
@@ -61,24 +61,24 @@ mod test {
     #[test]
     fn test_new_ice_gathering_state() {
         let tests = vec![
-            ("Unspecified", ICEGatheringState::Unspecified),
-            ("new", ICEGatheringState::New),
-            ("gathering", ICEGatheringState::Gathering),
-            ("complete", ICEGatheringState::Complete),
+            ("Unspecified", RTCIceGatheringState::Unspecified),
+            ("new", RTCIceGatheringState::New),
+            ("gathering", RTCIceGatheringState::Gathering),
+            ("complete", RTCIceGatheringState::Complete),
         ];
 
         for (state_string, expected_state) in tests {
-            assert_eq!(expected_state, ICEGatheringState::from(state_string));
+            assert_eq!(expected_state, RTCIceGatheringState::from(state_string));
         }
     }
 
     #[test]
     fn test_ice_gathering_state_string() {
         let tests = vec![
-            (ICEGatheringState::Unspecified, "Unspecified"),
-            (ICEGatheringState::New, "new"),
-            (ICEGatheringState::Gathering, "gathering"),
-            (ICEGatheringState::Complete, "complete"),
+            (RTCIceGatheringState::Unspecified, "Unspecified"),
+            (RTCIceGatheringState::New, "new"),
+            (RTCIceGatheringState::Gathering, "gathering"),
+            (RTCIceGatheringState::Complete, "complete"),
         ];
 
         for (state, expected_string) in tests {
